/**
	$Id: DummyService.java 6875 2015-04-20 09:08:18Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.service;

import java.util.Date;
import java.util.TimerTask;

import net.sf.basedb.core.Application;
import net.sf.basedb.util.Values;
import net.sf.basedb.util.extensions.ActionFactory;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	A dummy service implementation that prints out the current
	time on {@link System#out} every x seconds (default = 10) when 
	the service is running. It will also print out messages when the service 
	is started and stopped and in some other places.
	<p>
	The service is it's own action factory and controller.

	@author nicklas
	@version 2.8
	@base.modified $Date: 2015-04-20 11:08:18 +0200 (må, 20 apr 2015) $
*/
public class DummyService
	implements ServiceControllerAction, ActionFactory<ServiceControllerAction>
{

	private boolean running;
	private TimerTask timer;
	private long interval;
	private String extensionId;
	
	public DummyService()
	{
		this.interval = 10000;
	}
	
	/*
		From the ActionFactory interface
		--------------------------------
	*/
	@Override
	public ServiceControllerAction[] getActions(InvokationContext<? super ServiceControllerAction> context)
	{
		extensionId = context.getExtension().getId();
		return new ServiceControllerAction[] { this };
	}

	@Override
	public boolean prepareContext(InvokationContext<? super ServiceControllerAction> context)
	{
		return true;
	}
	// ---------------------------------------------

	/*
		From the ServiceControllerAction interface
		------------------------------------------
	*/
	@Override
	public boolean isRunning()
	{
		System.out.println(extensionId + " service is " + (running ? "running" : "not running"));
		return running;
	}

	@Override
	public void start()
	{
		if (running) return;
		System.out.println("Starting service: " + extensionId);
		if (timer == null)
		{
			timer = new TimerTask()
			{
				@Override
				public void run()
				{
					System.out.println(extensionId + ": " + new Date());
				}
			};
			timer = Application.getScheduler().schedule(timer, interval, interval, false);
		}
		running = true;
	}

	@Override
	public void stop()
	{
		if (!running) return;
		System.out.println("Stopping service: " + extensionId);
		if (timer != null)
		{
			timer.cancel();
			timer = null;
		}
		running = false;
	}
	// ---------------------------------------------
	
	/**
		Set the interval between writes to stdout.
		@param seconds The interval in seconds
	*/
	public void setInterval(String seconds)
	{
		this.interval = Values.getInt(seconds, 10) * 1000;
	}

	@Override
	public String toString()
	{
		return "DummyService[" + extensionId + "]";
	}
}
