/*
	$Id: ViewSpotImage.java 7159 2016-05-26 06:56:52Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/

package net.sf.basedb.clients.web.servlet;

import net.sf.basedb.clients.web.Base;
import net.sf.basedb.core.Application;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.RawBioAssay;
import net.sf.basedb.core.SpotImages;
import net.sf.basedb.core.SpotImage;
import net.sf.basedb.core.data.RawData;
import net.sf.basedb.core.InvalidDataException;

import net.sf.basedb.util.FileUtil;
import net.sf.basedb.util.Values;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.IOException;

/**
	 @author nicklas
	 @version 2.0
	 @base.modified $Date: 2016-05-26 08:56:52 +0200 (to, 26 maj 2016) $
*/

public final class ViewSpotImage
	extends HttpServlet
{

	/**
		
	*/
	private static final long serialVersionUID = 4627395145185119139L;

	@Override
	public void doGet(HttpServletRequest request, HttpServletResponse response)
		throws IOException, ServletException
	{
		String pathInfo = request.getPathInfo();
		/*
			The PATH_INFO is expected to be like:
			/SessionControl.ID/RawBioAssay.ID/RawData.id/filename
		*/
		String[] parameters = pathInfo.split("/");

		if (parameters.length < 4)
		{
			throw new ServletException("Invalid number of parameters: " + pathInfo);
		}
		
		final String ID = parameters[1];
		final int rawBioAssayId = Values.getInt(parameters[2]);
		final int rawId = Values.getInt(parameters[3]);
	
		DbControl dc = null;
		try
		{
			final SessionControl sc = Application.getSessionControl(ID, Base.WEBCLIENT_ID, request.getRemoteAddr(), true);
			dc = sc.newDbControl();
			
			RawBioAssay rba = RawBioAssay.getById(dc, rawBioAssayId);
			if (!rba.hasSpotImages()) throw new InvalidDataException("Raw bioassay doesn't have spot images: " + rba);
			
			RawData rd = rba.getRawDataById(rawId);
			SpotImages spi = rba.getSpotImages();
			SpotImage image = spi.getSpotImage(rd);
			
			response.setContentLength(image.getBytes());
			response.setContentType("image/png");
			response.setHeader("Cache-Control", "max-age=3600");
			InputStream in = image.getInputStream();
			OutputStream out = response.getOutputStream();
			FileUtil.copy(in, out);
			in.close();
			out.flush();
			out.close();
		}
		catch (Throwable ex)
		{
			throw new ServletException(ex);
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	@Override
	public void doPost(HttpServletRequest request, HttpServletResponse response)
		throws IOException, ServletException
	{
		doGet(request, response);
	}
}
