/*
	$Id: QueryElement.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Collection;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.BaseException;

/**
	A query element is used in various places in a {@link Query} to
	build the structure of the query. A query element is by itself not useful,
	only the subtypes of this interface are.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (må, 06 apr 2009) $
*/
public interface QueryElement
{
	/**
		Create a query language string of the query element. Use the {@link
		Query#getQueryType()} method to find out which query language is wanted
		in case the element requires different syntax for different languages.
		
		@param query The query that is about to be executed
		@param dc The <code>DbControl</code> object used to execute the query
		@throws UnsupportedOperationException If the requested query language is
			not supported by the query element
		@throws BaseException If there is any other error
	*/
	public String toQl(Query query, DbControl dc)
		throws BaseException;
	
	/**
		Get the children of this query element or null if it has no children.
		For example the {@link AddExpression} has two children, the expression
		beeing added.
		@return A collection or null
	*/
	public Collection<? extends QueryElement> getChildren();
	
}
