/**
	$Id: GenericDiskDataWriterFactory.java 5212 2010-01-12 13:21:49Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

/**
	Generic implementation of a data writer factory that create
	files on the local file system. The default file name generation
	will generate file names of the form 'sdata-1.txt', 'sdata-2.txt',
	and so on.
	
	@author Nicklas
	@version 2.15
	@base.modified $Date: 2010-01-12 14:21:49 +0100 (ti, 12 jan 2010) $
*/
public class GenericDiskDataWriterFactory<T>
	extends AbstractDataWriterFactory<T>
{

	private final java.io.File dir;
	
	/**
		Create a new factory that creates files in the given
		directory. The directory should already exist.
		@param dir The directory to create files in
		@throws NullPointerException If the dir parameter is null
		@throws FileNotFoundException If the given path is not an existing directory
	*/
	public GenericDiskDataWriterFactory(java.io.File dir, FilenameGenerator<T> filenameGenerator)
		throws IOException
	{
		super(filenameGenerator);
		if (dir == null) throw new NullPointerException("dir");
		if (!dir.isDirectory()) throw new FileNotFoundException(dir.toString());
		this.dir = dir;
	}
	
	/**
		Create a new file in the data directory with the given file
		name.
		@throws IOException If the file already exists or if it can't
			be created
	*/
	@Override
	protected OutputStream getOutputStream(String filename) 
		throws IOException
	{
		java.io.File file = new java.io.File(dir, filename);
		if (file.exists()) throw new IOException("File exists: " + file);
		return new FileOutputStream(file);
	}
}
