/**
	$Id $

	Copyright (C) 2017 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.events;

import net.sf.basedb.util.extensions.Extension;
import net.sf.basedb.util.extensions.ExtensionPoint;

/**
	Event filter that only passes events for a specific extension.

	@author nicklas
	@since 3.10
 */
public class ExtensionEventFilter
	implements EventFilter
{
	private final String id;
	private final EventType eventType;
	
	/**
		Create a new extension event filter.
		@param extension The extension to pass events for
		@param eventType The event type to pass events for, or null to pass all event types
	*/
	public ExtensionEventFilter(Extension<?> extension, EventType eventType)
	{
		this(extension.getId(), eventType);
	}
	
	/**
		Create a new extension event filter.
		@param id The ID of the extension point
		@param eventType The event type to pass events for, or null to pass all event types
	*/
	public ExtensionEventFilter(String id, EventType eventType)
	{
		this.id = id;
		this.eventType = eventType;
	}
	
	/**
		@return TRUE if the extension has the same ID as the one
			given in the constructor and if the event type matches
	*/
	@Override
	public boolean shouldSend(EventType event, ExtensionPoint<?> extensionPoint,
			Extension<?> extension)
	{
		return (eventType == null || eventType.equals(event)) 
			&& extension != null && id.equals(extension.getId());
	}

}
