/**
	$Id: IdentifiableFormatter.java 4925 2009-05-08 11:30:36Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.formatter;

import net.sf.basedb.core.Identifiable;

/**
 	Formatter to handle {@link Identifiable} items. The formatter
 	returns the ID of the item. This formatter can not parse strings.

	@author Nicklas
	@version 2.12
	@base.modified $Date: 2009-05-08 13:30:36 +0200 (fr, 08 maj 2009) $
*/
public class IdentifiableFormatter
	implements Formatter<Identifiable>
{
	private String nullValue = "";
	
	/**
		Create a new formatter. Null values are formatted as an empty string.
	*/
	public IdentifiableFormatter()
	{}
	
	/**
		Create a new formatter.
		@param nullValue The string to return if a null item is 
			passed to {@link #format(Identifiable)}
	*/
	public IdentifiableFormatter(String nullValue)
	{
		this.nullValue = nullValue;
	}

	/*
		From the Formatter interface
		-------------------------------------------
	*/
	@Override
	public String format(Identifiable value)
	{
		return value == null ? nullValue : Integer.toString(value.getId());
	}
	/**
		@throws UnsupportedOperationException Always
	*/
	@Override
	public Identifiable parseString(String value)
	{
		throw new UnsupportedOperationException("parseString: " + value);
	}
	// -------------------------------------------

}
