/**
	$Id: DataFileLoader.java 6959 2015-10-01 09:37:58Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;


import java.util.List;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.FileSet;
import net.sf.basedb.core.FileSetMember;
import net.sf.basedb.core.FileStoreEnabled;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.RootRawBioAssay;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.FileSetMemberNameGenerator;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for data files. Data files are
	normally loaded as an end-point folder node with one child entry
	for each data file. The exception is if there is only one file,
	in which case the file node itself is loaded. It can never be
	root node or a forward/reverse-loading node.
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2015-10-01 11:37:58 +0200 (to, 01 okt 2015) $
*/
public class DataFileLoader
	extends BasicItemNodeLoader<FileSetMember>
{
	
	public DataFileLoader()
	{
		super(Item.FILESETMEMBER, DENY_ROOT_NODE, new FileSetMemberNameGenerator());
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		NodeFactory<FileSetMember> nf = getNodeFactory(dc, context);
		Node folderNode = null;

		Item parentType = parentNode.getItemType();
		FileStoreEnabled parent = null;
		if (parentType == Item.ROOTRAWBIOASSAY)
		{
			// The parent may be a root raw bioasay if the overview starts at the
			// experiment level
			RootRawBioAssay root = (RootRawBioAssay)parentNode.getItem(dc);
			parent = root.getRawBioAssay();
		}
		else
		{
			parent = (FileStoreEnabled)parentNode.getItem(dc);
		}
		
		if (parent.hasFileSet())
		{
			FileSet fs = parent.getFileSet();
			ItemQuery<FileSetMember> query = context.initQuery(fs.getMembers(), "dataFileType.name");
			List<FileSetMember> files = query.list(dc);
			if (files.size() > 1)
			{
				folderNode = new Node("files", "Data files", parentNode, ChildNodeDirection.NONE);
			}
			else 
			{
				folderNode = parentNode;
			}
			for (FileSetMember member : files)
			{
				createItemNode(nf, member, member, false, folderNode, ChildNodeDirection.NONE);
			}
		}
		postValidateFolder(nf, folderNode, parentNode, false);
		return folderNode;
	}
	// -----------------------------------
	
}
