<%-- $Id: index.jsp 6414 2014-02-05 09:57:05Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.AnyToAny"
	import="net.sf.basedb.core.BasicItem"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.MultiPermissions"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.ItemAlreadyExistsException"
	import="net.sf.basedb.util.RemovableUtil"
	import="net.sf.basedb.util.ShareableUtil"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.util.HTML"
	import="java.util.Enumeration"
	import="java.util.Set"
	import="java.util.HashSet"
	import="java.util.List"
	import="java.util.ArrayList"
	import="java.util.Collections"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%!
	private static final ItemContext defaultContext = Base.createDefaultContext("name", "name,description");
	private static final Item itemType = Item.ANYTOANY;
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final String cmd = request.getParameter("cmd");
final String root = request.getContextPath()+"/";
final String mode = request.getParameter("mode");
final String callback = request.getParameter("callback");
final String itemId = request.getParameter("item_id");
final String listPage = "list_anytoany.jsp?ID="+ID
	+(mode == null ? "" : "&mode="+mode)
	+(callback == null ? "" : "&callback="+callback)
	+(itemId == null ? "" : "&item_id="+itemId);
final String editPage = "edit_anytoany.jsp?ID="+ID;

String forward = null;
String redirect = null;
String message = null;
DbControl dc = null;

try
{
	if ("ViewItem".equals(cmd))
	{
		// Display the view page for a single item 
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		forward = editPage;
	}
	else if ("EditItem".equals(cmd))
	{
		// Display the edit page for a single item (should be opened in a popup)
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = editPage;
	}
	else if ("NewItem".equals(cmd))
	{
		// Display the edit page for a new item (should be opened in a popup)
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		cc.setId(0);
		forward = editPage;
	}
	else if ("UpdateItem".equals(cmd))
	{
		// Update the properties on an item (will close the popup)
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, defaultContext);
		final int maxRecent = Base.getMaxRecent(sc);
		dc = sc.newDbControl();
		
		AnyToAny anyToAny = (AnyToAny)cc.getObject("item");
		if (anyToAny == null)
		{
			Item fromType = Item.valueOf(request.getParameter("from_type"));
			int fromId = Values.getInt(request.getParameter("from_id"));
			BasicItem from = fromType.getById(dc, fromId);

			Item toType = Item.valueOf(request.getParameter("to_type"));
			int toId = Values.getInt(request.getParameter("to_id"));
			BasicItem to = toType.getById(dc, toId);
			
			cc.setRecent("toTypes", toType.name(), maxRecent);
			
			String name = Values.getStringOrNull(request.getParameter("name"));
			
			anyToAny = AnyToAny.getNew(dc, from, to, name, false);
			dc.saveItem(anyToAny);
			message = "Link created";
		}
		else
		{
			dc.reattachItem(anyToAny, false);

			anyToAny.setName(Values.getStringOrNull(request.getParameter("name")));
			int toId = Values.getInt(request.getParameter("to_id"), -1);
			if (toId >= 0) // < 0 = denied or unchanged
			{
				BasicItem to = anyToAny.getToType().getById(dc, toId);
				anyToAny.setTo(to);
			}

			message = "Link updated";
		}

		anyToAny.setDescription(Values.getStringOrNull(request.getParameter("description")));
		anyToAny.setUsingTo(Values.getBoolean(request.getParameter("block_removal")));
		
		dc.commit();
		cc.removeObject("item");
	}
	else if ("DeleteItems".equals(cmd))
	{
		dc = sc.newDbControl();
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		int numTotal = cc.getSelected().size();
		int numDeleted = RemovableUtil.delete(dc, itemType, cc.getSelected());
		dc.commit();
		if (numTotal != numDeleted)
		{
			message = (numDeleted == 0 ? "No" : "Only "+numDeleted+" of "+numTotal) + " items could be unlinked, because you have no DELETE permission";
		}
		else
		{
			message = numDeleted + " items unlinked";
		}
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}
}
finally
{
	if (dc != null) dc.close();
}

if (forward != null)
{
	sc.setSessionSetting("alert-message", message);
	pageContext.forward(forward);
}
else if (redirect != null)
{
	sc.setSessionSetting("alert-message", message);
	response.sendRedirect(redirect);
}
else if (message == null)
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&wait=0");
}
else
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&message="+HTML.urlEncode(message));
}
%>

